@@ -263,7 +263,7 @@ async def on_message(message):
                     print(str(DM_error))
             if command_dict[c]["disconnect_from_voice_channel"] != False:
                 try:
-                    await message.guild.voice_object.disconnect()
+                    await message.guild.voice_client.disconnect()
                 except Exception as disconnect_error:
                     print(disconnect_error)
 
